@@ -33,4 +33,7 @@ async def asyncList_columns(table_name=None):
 
 async def asyncCallRequest(endpoint,*args,**kwargs):
   url = getEndpointUrl(endpoint)
-  return await asyncPostRequest(url,kwargs,endpoint=endpoint)
+  return await asyncPostRequest(url,kwargs)
+
+def solcatcherPostRequest(endpoint,**kwargs):
+    return asyncio.run(asyncCallRequest(endpoint,**kwargs))
