@@ -8,7 +8,9 @@ async def async_get_rate_limit_url(method_name, *args, **kwargs):
         if "method" not in kwargs:
             kwargs["method"] = arg
     return await asyncGetRequest(url, kwargs)
-    
+
+
+
 async def async_log_response(method_name, response_data,endpoint=None, *args, **kwargs):
     url = getEndpointUrl("/log_response")
     # Assuming that `args` is supposed to update `kwargs` for unspecified keys
@@ -18,10 +20,9 @@ async def async_log_response(method_name, response_data,endpoint=None, *args, **
         if "response_data" not in kwargs:
             kwargs["response_data"] = response_data
     # Use a direct payload if kwargs are not being used effectively
-    payload = {
-        "method": kwargs.get("method", method_name),
-        "response_data": kwargs.get("response_data", response_data)
-    }
+    kwargs["response_data"] = response_data
+    kwargs["method"] = method_name
+
     return await asyncPostRequest(url, kwargs,endpoint=None)
 
 
